@@ -226,7 +226,7 @@ def sendMessage():
     if request.method == 'POST':
         msg = request.form['fmsg']
         interface.sendText(msg, wantAck=True)
-    return redirect(url_for('index'))
+    return redirect(url_for('configPage'))
 
 @app.route('/setNode', methods=['POST'])
 @basic_auth.required
@@ -298,7 +298,7 @@ def login():
         if not is_safe_url(next):
             return flask.abort(400)
 
-        return flask.redirect(next or flask.url_for('index'))
+        return flask.redirect(next or flask.url_for('indexPage'))
     return flask.render_template('login.html', form=form)
 
 def main():
